@@ -2,7 +2,7 @@ import os
 import numpy as np
 import pandas as pd
 from rpy2.robjects.packages import importr
-from rpy2.robjects import FloatVector, numpy2ri
+from rpy2.robjects import FloatVector
 from datetime import datetime
 
 
@@ -42,8 +42,11 @@ class DynamicRegressor():
         # obtain time series forecast -----
 
         input_series = df.drop(columns=['date']).values
-        y = stats.ts(FloatVector([item for sublist in input_series.tolist() for item in sublist]))
-        self.fcast = ahead.dynrmf(y, h=self.h, level=self.level, type_pi=self.type_pi)        
+        y = stats.ts(FloatVector([item for sublist in input_series.tolist() for item in sublist]))                
+        print("y")
+        print(y)
+        print("\n")
+        self.fcast = ahead.dynrmf(y=y, h=self.h, level=self.level, type_pi=self.type_pi)         
 
 
         # result -----
